@@ -32,7 +32,8 @@ void Redraw(int x, int y, int WhichPlayer)
     int i,DoNotBlit;
     SDL_Surface *Pic;
     
-    for (i=0;i<BaPlayer[WhichPlayer].CannonNum;i++) {
+    // Cannons
+    for (i=0; i<BaPlayer[WhichPlayer].CannonNum; i++) {
 	if (  (BaPlayer[WhichPlayer].Cannon[i].x==x)
 	    &&(BaPlayer[WhichPlayer].Cannon[i].y==y)) {
 	    DoNotBlit=0;
@@ -61,6 +62,7 @@ void Redraw(int x, int y, int WhichPlayer)
 	    }
 	}
     }
+    // Castles
     for (i=0;i<CastleNum;i++) {
 	if (  (Castle[i].x==x)
 	    &&(Castle[i].y==y)) {
@@ -72,6 +74,7 @@ void Redraw(int x, int y, int WhichPlayer)
 	    BlitToBB(x*BSIZE, y*BSIZE, Pic);
 	}
     }
+    // Garbage
     if (Garbage[x][y]) {
 	SDL_SetAlpha(GarbagePic, SDL_SRCALPHA, 255-(3-Garbage[x][y])*255/3);
 	Blit(x*BSIZE, y*BSIZE, GarbagePic);
@@ -80,6 +83,69 @@ void Redraw(int x, int y, int WhichPlayer)
     }
 }
 
+void RedrawEverything()
+{
+    int i, x, y, WhichPlayer;
+    SDL_Surface *Pic;
+
+    SDL_BlitSurface(BackPic, NULL, Screen, NULL);
+    
+    // Houses, Garbage and Walls
+    for (x=0; x<Width; x++) {
+	for (y=0; y<Height; y++) {
+
+	    for (WhichPlayer=0; WhichPlayer<PlayerNum; WhichPlayer++)
+		if (BPlayer[WhichPlayer].Secured[x][y])
+		    Blit(x*BSIZE, y*BSIZE, BPlayer[Landscape[x][y]].Ground);
+	    
+	    if (House[x][y])
+		Blit(x*BSIZE, y*BSIZE, HousePic);
+	    
+	    if (Garbage[x][y]) {
+		SDL_SetAlpha(GarbagePic, SDL_SRCALPHA, 255-(3-Garbage[x][y])*255/3);
+		Blit(x*BSIZE, y*BSIZE, GarbagePic);
+		SDL_SetAlpha(GarbagePic, 0, 0);
+	    }
+	    
+	    if (Wall[x][y]) {
+		BlitTo( Screen, x*BSIZE, y*BSIZE, BPlayer[Landscape[x][y]].Wall );
+	    }
+	}	
+    }
+
+    // Castles
+    for (i=0;i<CastleNum;i++) {
+        if (Castle[i].Type == 1)
+	    Blit(Castle[i].x*BSIZE, Castle[i].y*BSIZE, CastlePic);
+	else
+	    Blit(Castle[i].x*BSIZE, Castle[i].y*BSIZE, BigCastlePic);
+    }
+
+    // Cannons
+    for (WhichPlayer=0; WhichPlayer<PlayerNum; WhichPlayer++) {
+	for (i=0; i<BaPlayer[WhichPlayer].CannonNum ;i++) {
+    	    if (BaPlayer[WhichPlayer].Cannon[i].Type == 0) {
+		if (BaPlayer[WhichPlayer].Cannon[i].Destroyed)
+		    Pic = CannonDestroyedPic[BaPlayer[WhichPlayer].Cannon[i].Destroyed-1];
+		else
+		    Pic = CannonPic[0];
+	    } else {
+		if (BaPlayer[WhichPlayer].Cannon[i].Destroyed)
+		    Pic = BigCannonDestroyedPic[BaPlayer[WhichPlayer].Cannon[i].Destroyed-1];
+		else
+		    Pic = BigCannonPic[0];
+	    }
+    	    Blit(BaPlayer[WhichPlayer].Cannon[i].x*BSIZE, BaPlayer[WhichPlayer].Cannon[i].y*BSIZE, Pic);
+	}
+    }
+    
+    // Tanks
+    for (i=0; i<TankNum; i++) {
+	DrawTank(i);
+    }
+    SDL_BlitSurface(Screen, NULL, BackBuffer, NULL);
+}
+
 void ConquerCannon(int x, int y)
 {
     int WhichPlayer,can;
