@@ -26,7 +26,7 @@ void ShowText(char *text);
 #define BATTLE_PHASE 3
 
 double Speed;
-int PlayerNum,LocalPlayerNum,CastleNum,EndGame,Width,Height,Phase,Conquer;
+int PlayerNum, LocalPlayerNum, CastleNum, EndGame, Width, Height, Phase, Conquer, RoundNum;
 char SelectFinished[PLAYERNUM],Selected[PLAYERNUM];
 Uint32 Now;
 Sint8 Wall[WIDTH][HEIGHT];
