@@ -26,9 +26,13 @@
 // Castle Selection
 #define NET_OTHER_SELECTION 30
 #define NET_SELECTION_FINISHED 31
-
 #define NET_CASTLE_RANDOMIZE 40
 
+// Sync Commands
+#define NET_SYNC_WALL 50
+#define NET_SYNC_GARBAGE 51
+#define NET_SYNC_HOUSE 52
+
 // Port number
 #define MAKE_NUM(A, B, C, D)	(((A+B)<<8)|(C+D)) /* Convert four letters into a number */
 #define NET_PORT	MAKE_NUM('c','a','c','o')
